@@ -51,7 +51,7 @@ int main(int argc, char **argv) {
 	app.setApplicationName("qalculate-qt");
 	app.setApplicationDisplayName("Qalculate!");
 	app.setOrganizationName("qalculate");
-	app.setApplicationVersion("4.9.0");
+	app.setApplicationVersion("5.0.0");
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 	app.setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
@@ -220,6 +220,15 @@ int main(int argc, char **argv) {
 
 	CALCULATOR->loadLocalDefinitions();
 
+	Unit *u = CALCULATOR->getActiveUnit("L");
+	if(u) settings->volume_category = u->category();
+	u = CALCULATOR->getActiveUnit("teaspoon");
+	if(u && u->category().find(settings->volume_category) == 0) settings->alternative_volume_categories.push_back(u->category());
+	u = CALCULATOR->getActiveUnit("gal");
+	if(u && u->category().find(settings->volume_category) == 0) settings->alternative_volume_categories.push_back(u->category());
+	u = CALCULATOR->getActiveUnit("UK_gal");
+	if(u && u->category().find(settings->volume_category) == 0) settings->alternative_volume_categories.push_back(u->category());
+
 	settings->setCustomAngleUnit();
 	settings->updateFavourites();
 
